/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.model;

import java.io.Serializable;
import java.util.Date;

/**
 * abstract base class for sensor data
 *
 * @author Merijn Zengers
 */
public class SensorData extends SensorBean implements Serializable {

    private SensorRun sensorRun;
    /**
     * X
     */
//    @Index
    private double longitude;
    /**
     * Y
     */
//    @Index
    private double latitude;
    private Double ndvi;
    private Double wdvi;
    private Double reading1;
    private Double reading2;
    private Double reading3;
    private Date utcTime;
    private Double speed;
    private Double course;

    public SensorData() {
    }

    public SensorData(double longitude, double latitude) {
        this.latitude = latitude;
        this.longitude = longitude;
    }

    public Double getNdvi() {
        return ndvi;
    }

    public void setNdvi(Double ndvi) {
        this.ndvi = ndvi;
    }

    public Double getWdvi() {
        return wdvi;
    }

    public void setWdvi(Double wdvi) {
        this.wdvi = wdvi;
    }

    public Double getCourse() {
        return course;
    }

    public void setCourse(Double course) {
        this.course = course;
    }


    public double getLatitude() {
        return latitude;
    }

    public void setLatitude(double latitude) {
        this.latitude = latitude;
    }

    public double getLongitude() {
        return longitude;
    }

    public void setLongitude(double longitude) {
        this.longitude = longitude;
    }

    public Double getReading1() {
        return reading1;
    }

    public void setReading1(Double reading1) {
        this.reading1 = reading1;
    }

    public Double getReading2() {
        return reading2;
    }

    public void setReading2(Double reading2) {
        this.reading2 = reading2;
    }

    public Double getReading3() {
        return reading3;
    }

    public void setReading3(Double reading3) {
        this.reading3 = reading3;
    }

    public SensorRun getSensorRun() {
        return sensorRun;
    }

    public void setSensorRun(SensorRun sensorRun) {
        this.sensorRun = sensorRun;
    }

    public Double getSpeed() {
        return speed;
    }

    public void setSpeed(Double speed) {
        this.speed = speed;
    }

    public Date getUtcTime() {
        return utcTime;
    }

    public void setUtcTime(Date utcTime) {
        this.utcTime = utcTime;
    }

    @Override
    public boolean equals(Object obj) {
        if (!super.equals(obj)) {
            return false;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final SensorData other = (SensorData) obj;
        if (this.sensorRun != other.sensorRun && (this.sensorRun == null || !this.sensorRun.equals(other.sensorRun))) {
            return false;
        }
        if (Double.doubleToLongBits(this.longitude) != Double.doubleToLongBits(other.longitude)) {
            return false;
        }
        if (Double.doubleToLongBits(this.latitude) != Double.doubleToLongBits(other.latitude)) {
            return false;
        }
        if (this.ndvi != other.ndvi && (this.ndvi == null || !this.ndvi.equals(other.ndvi))) {
            return false;
        }
        if (this.wdvi != other.wdvi && (this.wdvi == null || !this.wdvi.equals(other.wdvi))) {
            return false;
        }
        if (this.reading1 != other.reading1 && (this.reading1 == null || !this.reading1.equals(other.reading1))) {
            return false;
        }
        if (this.reading2 != other.reading2 && (this.reading2 == null || !this.reading2.equals(other.reading2))) {
            return false;
        }
        if (this.reading3 != other.reading3 && (this.reading3 == null || !this.reading3.equals(other.reading3))) {
            return false;
        }
        if (this.utcTime != other.utcTime && (this.utcTime == null || !this.utcTime.equals(other.utcTime))) {
            return false;
        }
        if (this.speed != other.speed && (this.speed == null || !this.speed.equals(other.speed))) {
            return false;
        }
        if (this.course != other.course && (this.course == null || !this.course.equals(other.course))) {
            return false;
        }
        return true;
    }

    @Override
    public int hashCode() {
        int hash = super.hashCode();
        hash = 13 * hash + (this.sensorRun != null ? this.sensorRun.hashCode() : 0);
        hash = 13 * hash + (int) (Double.doubleToLongBits(this.longitude) ^ (Double.doubleToLongBits(this.longitude) >>> 32));
        hash = 13 * hash + (int) (Double.doubleToLongBits(this.latitude) ^ (Double.doubleToLongBits(this.latitude) >>> 32));
        hash = 13 * hash + (this.ndvi != null ? this.ndvi.hashCode() : 0);
        hash = 13 * hash + (this.wdvi != null ? this.wdvi.hashCode() : 0);
        hash = 13 * hash + (this.reading1 != null ? this.reading1.hashCode() : 0);
        hash = 13 * hash + (this.reading2 != null ? this.reading2.hashCode() : 0);
        hash = 13 * hash + (this.reading3 != null ? this.reading3.hashCode() : 0);
        hash = 13 * hash + (this.utcTime != null ? this.utcTime.hashCode() : 0);
        hash = 13 * hash + (this.speed != null ? this.speed.hashCode() : 0);
        hash = 13 * hash + (this.course != null ? this.course.hashCode() : 0);
        return hash;
    }
}
