/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.model;

import java.io.Serializable;

/**
 * Metadata for a sensorFile 
 * @author Merijn Zengers
 */
public class SensorMetadata implements Serializable {


    private String dateFormat;

    private int sensorHeight;

    private int numberOfSensors;

    private String sensorSpread;


    private String sensorType;

    private String spectralChannels;


    protected SensorMetadata() {
    }

    public SensorMetadata(String dateFormat, int sensorHeight, int numberOfSensors, String sensorSpread, String sensorType, String spectralChannels) {
        this.dateFormat = dateFormat;
        this.sensorHeight = sensorHeight;
        this.numberOfSensors = numberOfSensors;
        this.sensorSpread = sensorSpread;
        this.sensorType = sensorType;
        this.spectralChannels = spectralChannels;

    }

    public String getDateFormat() {
        return dateFormat;
    }

    public void setDateFormat(String dateFormat) {
        this.dateFormat = dateFormat;
    }

    public int getSensorHeight() {
        return sensorHeight;
    }

    public void setSensorHeight(int sensorHeight) {
        this.sensorHeight = sensorHeight;
    }

    public int getNumberOfSensors() {
        return numberOfSensors;
    }

    public void setNumberOfSensors(int numberOfSensors) {
        this.numberOfSensors = numberOfSensors;
    }

    public String getSensorSpread() {
        return sensorSpread;
    }

    public void setSensorSpread(String sensorSpread) {
        this.sensorSpread = sensorSpread;
    }

    public String getSensorType() {
        return sensorType;
    }

    public void setSensorType(String sensorType) {
        this.sensorType = sensorType;
    }

    public String getSpectralChannels() {
        return spectralChannels;
    }

    public void setSpectralChannels(String spectralRange) {
        this.spectralChannels = spectralRange;
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final SensorMetadata other = (SensorMetadata) obj;
        if ((this.dateFormat == null) ? (other.dateFormat != null) : !this.dateFormat.equals(other.dateFormat)) {
            return false;
        }
        if (this.sensorHeight != other.sensorHeight) {
            return false;
        }
        return true;
    }

    @Override
    public int hashCode() {
        int hash = 3;
        hash = 11 * hash + (this.dateFormat != null ? this.dateFormat.hashCode() : 0);
        hash = 11 * hash + this.sensorHeight;
        return hash;
    }
}
